==> mxcolr-0.0.2-3.tgz: package/README.md <==
<p align="center">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://raw.githubusercontent.com/wiki/metaory/mxcolr-cli/assets/card.png">
    <source media="(prefers-color-scheme: light)" srcset="https://raw.githubusercontent.com/wiki/metaory/mxcolr-cli/assets/card.png">
    <img width="90%" alt="mxcolr" src="https://raw.githubusercontent.com/wiki/metaory/mxcolr-cli/assets/card.png">
  </picture>
  <br>
  <a href="#why">Why</a> |
  <a href="#installation">Installation</a> |
  <a href="#usage">Usage</a> |
  <a href="#options">Options</a> |
  <a href="#config">Config</a> |
  <a href="#videos">Videos</a>
</p>


<div align="center">
  <a href="https://npmjs.org/package/mxcolr">
    <img src="https://img.shields.io/npm/v/mxcolr" alt="NPM Version"/>
  </a>
  <a href="https://npmjs.org/package/mxcolr">
    <img src="https://img.shields.io/npm/dm/mxcolr" alt="NPM Downloads"/>
  </a>
  <a href="https://github.com/metaory/mxcolr-cli/actions/workflows/main.yml">
    <img src="https://img.shields.io/github/workflow/status/metaory/mxcolr-cli/MXFlow%20npm%20Package" alt="GH Status"/>
  </a>
  <a href="https://github.com/metaory/mxcolr-cli">
    <img src="https://img.shields.io/github/languages/code-size/metaory/mxcolr-cli" alt="Code Size"/>
  </a>
</div>


<p align="center">
  :zap: ヘ Generate, Preview and Apply beautiful unified human friendly pseudo random color schemes, SYSTEM WIDE!
</p>


<p align="center">
  <img width="75%" src="https://raw.githubusercontent.com/wiki/metaory/mxcolr-cli/assets/screenshot.png">
</p>

Roadmap
=======

- [X] basic cli structure
- [X] basic seed generation
- [X] basic palette generation
- [X] basic shade generation
- [X] basic export
- [ ] yaml config
- [ ] template replacement
- [ ] advance export
- [ ] intro demo
- [ ] completion

---

:warning: mxcolr-cli is in an early state of release. Breaking changes may be made to APIs/core structures as the tool matures.

License
-------

[MIT](LICENSE)

==> mxcolr-0.0.2-4.tgz: package/README.md <==
<p align="center">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://raw.githubusercontent.com/wiki/metaory/mxcolr-cli/assets/card.png">
    <source media="(prefers-color-scheme: light)" srcset="https://raw.githubusercontent.com/wiki/metaory/mxcolr-cli/assets/card.png">
    <img width="90%" alt="mxcolr" src="https://raw.githubusercontent.com/wiki/metaory/mxcolr-cli/assets/card.png">
  </picture>
  <br>
  <a href="#why">Why</a> |
  <a href="#installation">Installation</a> |
  <a href="#usage">Usage</a> |
  <a href="#options">Options</a> |
  <a href="#config">Config</a> |
  <a href="#videos">Videos</a>
</p>


<div align="center">
  <a href="https://npmjs.org/package/mxcolr">
    <img src="https://img.shields.io/npm/v/mxcolr" alt="NPM Version"/>
  </a>
  <a href="https://npmjs.org/package/mxcolr">
    <img src="https://img.shields.io/npm/dm/mxcolr" alt="NPM Downloads"/>
  </a>
  <a href="https://github.com/metaory/mxcolr-cli/actions/workflows/main.yml">
    <img src="https://img.shields.io/github/workflow/status/metaory/mxcolr-cli/npm-package" alt="GH Status"/>
  </a>
  <a href="https://github.com/metaory/mxcolr-cli">
    <img src="https://img.shields.io/github/languages/code-size/metaory/mxcolr-cli" alt="Code Size"/>
  </a>
</div>


<p align="center">
  :zap: ヘ Generate, Preview and Apply beautiful unified human friendly pseudo random color schemes, SYSTEM WIDE!
</p>


<p align="center">
  <img width="75%" src="https://raw.githubusercontent.com/wiki/metaory/mxcolr-cli/assets/screenshot.png">
</p>

Roadmap
=======

- [X] basic cli structure
- [X] basic seed generation
- [X] basic palette generation
- [X] basic shade generation
- [X] basic export
- [ ] yaml config
- [ ] template replacement
- [ ] advance export
- [ ] intro demo
- [ ] completion

---

:warning: mxcolr-cli is in an early state of release. Breaking changes may be made to APIs/core structures as the tool matures.

License
-------

[MIT](LICENSE)
